package sun.awt.image;

import java.awt.image.ImageProducer;
import java.awt.Color;
import java.awt.GraphicsEnvironment;
import sun.java2d.SunGraphics2D;
import sun.java2d.SurfaceData;
import java.awt.SystemColor;
import java.awt.Graphics2D;
import java.awt.Graphics;
import java.awt.image.WritableRaster;
import java.awt.image.ColorModel;
import java.awt.Font;
import java.awt.Component;
import java.awt.image.BufferedImage;

public class OffScreenImage extends BufferedImage
{
    protected Component c;
    private OffScreenImageSource osis;
    private Font defaultFont;
    
    public OffScreenImage(Component c, ColorModel cm, WritableRaster raster, boolean isRasterPremultiplied) {
        super(cm, raster, isRasterPremultiplied, null);
        this.c = c;
        this.initSurface(raster.getWidth(), raster.getHeight());
    }
    
    @Override
    public Graphics getGraphics() {
        return this.createGraphics();
    }
    
    @Override
    public Graphics2D createGraphics() {
        if (this.c == null) {
            return GraphicsEnvironment.getLocalGraphicsEnvironment().createGraphics(this);
        }
        Color bg = this.c.getBackground();
        if (bg == null) {
            bg = SystemColor.window;
        }
        Color fg = this.c.getForeground();
        if (fg == null) {
            fg = SystemColor.windowText;
        }
        Font f = this.c.getFont();
        if (f == null) {
            if (this.defaultFont == null) {
                this.defaultFont = new Font("Dialog", 0, 12);
            }
            f = this.defaultFont;
        }
        return new SunGraphics2D(SurfaceData.getPrimarySurfaceData(this), fg, bg, f);
    }
    
    private void initSurface(int n, int n2) {
        Graphics2D graphics = this.createGraphics();
        try {
            graphics.clearRect(0, 0, n, n2);
        }
        finally {
            graphics.dispose();
        }
    }
    
    @Override
    public ImageProducer getSource() {
        if (this.osis == null) {
            this.osis = new OffScreenImageSource(this);
        }
        return this.osis;
    }
}
